Gesture

Struct Gesture 

pub struct Gesture {
    pub points: Vec<Point>,
    pub points_raw: Vec<Point>,
    pub name: String,
    pub lut: Option<Vec<Vec<usize>>>,
}
Implements a gesture as a cloud of points (i.e., an unordered set of points). For $P, gestures are normalized with respect to scale, translated to origin, and resampled into a fixed number of 32 points. For $Q, a LUT is also computed.

Fields

points: Vec<Point>

Gesture points (normalized)

points_raw: Vec<Point>

Gesture points (not normalized, as captured from the input device)

name: String

Gesture class

lut: Option<Vec<Vec<usize>>>

Look-up table

Implementations

Source

impl Gesture

pub fn new(pts: Vec<Point>, name: &str) -> Self

Constructs a new gesture from a list of points and a name

pub fn normalize(&mut self, compute_lut: bool)

Normalizes the gesture path. The $Q recognizer requires an extra normalization step, the computation of the LUT, which can be enabled with the computeLUT parameter.