Module point_cloud_recognizer

Module point_cloud_recognizer 

Functions

classify
Main function of the $P recognizer. Classifies a candidate gesture against a set of training samples. Returns the class of the closest neighbor in the training set.