classify

Function classify 

pub fn classify(candidate: &Gesture, training_set: &[Gesture]) -> String
Main function of the $P recognizer. Classifies a candidate gesture against a set of training samples. Returns the class of the closest neighbor in the training set.