Module point_cloud_recognizer_plus

Module point_cloud_recognizer_plus 

Functions

classify
Main function of the $P+ recognizer. Classifies a candidate gesture against a set of training samples. Returns the class of the closest neighbor in the template set.
compute_local_shape_descriptors
Computes local shape descriptors (theta turning angles) at each point on the gesture path.