pub struct Gesture {
pub points: Vec<Point>,
pub points_raw: Vec<Point>,
pub name: String,
pub lut: Option<Vec<Vec<usize>>>,
}Expand description
Implements a gesture as a cloud of points (i.e., an unordered set of points). For $P, gestures are normalized with respect to scale, translated to origin, and resampled into a fixed number of 32 points. For $Q, a LUT is also computed.
Fields
points: Vec<Point>Gesture points (normalized)
points_raw: Vec<Point>Gesture points (not normalized, as captured from the input device)
name: StringGesture class
lut: Option<Vec<Vec<usize>>>Look-up table
Implementations