q_
recognizer
0.1.0
Module point_
cloud_
recognizer
Module Items
Functions
In crate q_
recognizer
q_recognizer
Module
point_cloud_recognizer
Functions

classify
Main function of the $P recognizer. Classifies a candidate gesture against a set of training samples. Returns the class of the closest neighbor in the training set.