Functions
- classify
- Main function of the $P+ recognizer. Classifies a candidate gesture against a set of training samples. Returns the class of the closest neighbor in the template set.
- compute_
local_ shape_ descriptors - Computes local shape descriptors (theta turning angles) at each point on the gesture path.