pub fn classify(
candidate: &Gesture,
template_set: &[Gesture],
params: &QParameters,
) -> ClassifyResultExpand description
Main function of the $Q recognizer. Classifies a candidate gesture against a set of templates. Returns the class of the closest neighbor in the template set.